pub struct WorkspaceUpdateParameters {
pub tags: Option<Value>,
pub properties: Option<WorkspacePropertiesUpdateParameters>,
}Expand description
The parameters for updating a machine learning team account workspace.
Fields
The resource tags for the machine learning team account workspace.
properties: Option<WorkspacePropertiesUpdateParameters>The parameters for updating the properties of a machine learning team account workspace.
Implementations